#########################################
#######Set the working directories#######
#########################################
RawData = ("F:/Guillaume_Charron/Scripts_and_Data/New_Analysis/Data/00_RawData")
DescFiles = ("F:/Guillaume_Charron/Scripts_and_Data/New_Analysis/Data/01_DescFiles")
Results = ("F:/Guillaume_Charron/Scripts_and_Data/New_Analysis/Data/02_Results/")
Graphs = ("F:/Guillaume_Charron/Scripts_and_Data/New_Analysis/Data/03_Graphs/")

####################################

dir.create(Results)
dir.create(Graphs)


#############################################################
#######analysis of the experiment with mixtools library######
#############################################################
setwd(DescFiles)
straininfo= read.csv("list_freeze_thawBC.csv", sep="\t", header=T)

library(mixtools)

setwd(RawData)

exp= read.table("Freeze_thaw_data_exp.csv", sep="\t", header=T)
ctrl= read.table("Freeze_thaw_data_control.csv", sep="\t", header=T)

strains = names(exp)


####for each strain find the two distribution with the normalmixEM#######
###if the mean of the distribution 1 >= 450, use the other distribution####
###this ensure that the distribution on the left is always used#########
###as the live (non fluorescent) distribution. Then establish the live/dead####
###threshold as mu(mean) + 3x sigma (std dev.) of the left distribution#######
###***when there are too few counts to have a good std*3, we######
###establish it as 600 (in the control there are very few cells past this point)###
###this can only lead to underestimation of the number of dead cells######
###plot the hist with the curves and add the threshold line########
###put the survival % result and take it into a file####

set.seed(1)

setwd(Graphs)
survival={}
pdf("Freeze_thaw_results.pdf")
par(mfrow = c(2,2))
for (i in 1:length(strains)){
	
	sub=exp[i]
	mixEM = normalmixEM(sub[,1], k=2)
	if (mixEM$mu[1] >= 450) {
		std3 = (3*mixEM$sigma[2]) + mixEM$mu[2]
		} else{
		std3 = (3*mixEM$sigma[1]) + mixEM$mu[1]
		}
	if (std3 >= 725) {
		std3 = 600
		}
	
	cdf= ecdf(sub[,1])
	per = round(cdf(std3),+3)
	per2 = mixEM$lambda
	hc1 = plot.mixEM(mixEM,whichplot=2, main2=paste(names(sub), "survival =", per),cex.main=1, ylab2="counts", xlab2="fluorescence")
		abline(v=std3, col="red")
	survival = rbind(survival, per)
}	
dev.off()


row.names(survival) = strains

#####subset the file to obtain a column with replicate strains (no number and ".1")

rep1 = subset(survival, grepl("\\.1",row.names(survival))== "FALSE")
rep2 = subset(survival, grepl("\\.1",row.names(survival))== "TRUE")

#################replace value of 91_202_x_GB20 with the value of 91_202_x_GB20.2 and remove 91_202_x_GB20.2
strains_rep1 = row.names(rep1)
strains_rep1 = strains_rep1[-44]
rep1[34] = rep1[44]

#####remove line 44 (91_202_x_GB_20.2)
rep1 = rep1[-44]
rep1 = as.data.frame(rep1)
######add row names
row.names(rep1) = strains_rep1
######order by row names
rep1 = rep1[order(row.names(rep1)),]
rep1 = as.data.frame(rep1)
######add ordered row names
row.names(rep1) = sort(strains_rep1)

###########for rep2
rep2 = rep2[order(row.names(rep2)),]
rep2 = as.data.frame(rep2)


######bind rep1 and rep2
percent_survival = cbind(rep1, rep2[,1])

######calculate the Pearson's R for the survival data
correlation = cor.test(percent_survival[,1], percent_survival[,2])

#####calculate the average for both replicate
avg = as.data.frame(apply(percent_survival, 1 , FUN = mean))

######bind percent_survival and avg
percent_survival = cbind (percent_survival, avg)
colnames(percent_survival) = c("rep1", "rep2","average")

#####change names with X before numbers####
row.names(percent_survival)[29] = "79_140_W"
row.names(percent_survival)[30] = "79_140_x_SQ107"
row.names(percent_survival)[31] = "91_202_W"
row.names(percent_survival)[32] = "91_202_x_GB20"
row.names(percent_survival)[33] = "91_202_x_SQ130"


#####add the info for strains
percent_survival = cbind(row.names(percent_survival), percent_survival)
colnames(percent_survival) = c("strain", "rep1", "rep2","average")
survival_info = merge(straininfo, percent_survival, by = "strain", all.y=T)

#####remove line 7 as is is not the right strain (contaminated well)
survival_info = survival_info[c(-7),]

#####simplify the dataframe

simplified_survival = survival_info[seq(1,86,2),c(1,4,8)]
condition = rep("Freeze_thaw", 43)
condition_type = rep("Climatic",43)
simplified_survival = cbind(simplified_survival, condition, condition_type)
colnames(simplified_survival) = c("strain", "group", "average", "condition", "cond_type")

#####put the data columns in the same order as in the screen
simplified_survivalBC = simplified_survival[,c(1,4,5,2,3)]

######remove CRL2_W as it is not part of the experiment

simplified_survivalBC = simplified_survivalBC[-6,]

########Do the same analysis for the BB and CC crosses
setwd(RawData)

replicateBBCC_1 = read.table("Freeze_repBBCC1.csv", sep="\t", header =T)
replicateBBCC_2 = read.table("Freeze_repBBCC2.csv", sep="\t", header =T)

strains = colnames(replicateBBCC_1)

set.seed(1)

#######Generate the graphs of cell survival
setwd(Graphs)

survivalrep1={}
pdf("Freeze_thaw_hist_BBCC1.pdf")
par(mfrow = c(2,2))
for (i in 1:length(replicateBBCC_1)){
	
	sub=replicateBBCC_1[i]
	mixEM = normalmixEM(sub[,1], k=2)
	if (mixEM$mu[1] >= 450) {
		std3 = (3*mixEM$sigma[2]) + mixEM$mu[2]
		} else{
		std3 = (3*mixEM$sigma[1]) + mixEM$mu[1]
		}
	if (std3 >= 725) {
		std3 = 600
		}
	
	cdf= ecdf(sub[,1])
	per = round(cdf(std3),+3)
	hc1 = plot.mixEM(mixEM,whichplot=2, main2=paste(names(sub), "survival =", per),cex.main=1, ylab2="counts", xlab2="fluorescence")
		abline(v=std3, col="red")
	survivalrep1 = rbind(survivalrep1, per)
}	
dev.off()


row.names(survivalrep1) = strains


survivalrep2={}
pdf("Freeze_thaw_hist_BBCC2.pdf")
par(mfrow = c(2,2))
for (i in 1:length(replicateBBCC_2)){
	
	sub=replicateBBCC_2[i]
	mixEM = normalmixEM(sub[,1], k=2)
	if (mixEM$mu[1] >= 450) {
		std3 = (3*mixEM$sigma[2]) + mixEM$mu[2]
		} else{
		std3 = (3*mixEM$sigma[1]) + mixEM$mu[1]
		}
	if (std3 >= 725) {
		std3 = 600
		}
	
	cdf= ecdf(sub[,1])
	per = round(cdf(std3),+3)
	hc1 = plot.mixEM(mixEM,whichplot=2, main2=paste(names(sub), "survival =", per),cex.main=1, ylab2="counts", xlab2="fluorescence")
		abline(v=std3, col="red")
	survivalrep2 = rbind(survivalrep2, per)
}	
dev.off()


row.names(survivalrep2) = strains


survival = cbind(survivalrep1, survivalrep2[,1])
###mean per strain
survival = cbind(survival,apply(survival, 1, FUN=mean))
survival = cbind(survival, c("BB","BB","CC","BB","BB","CC","CC","CC","BB","BB","CC","BB","CC","CC","BB","BB","BB","BB","BB","BB"))

#####simplify the dataframe

condition = rep("Freeze_thaw", 20)
condition_type = rep("Climatic",20)
survival= cbind(row.names(survival),survival, condition, condition_type)
attributes(survival)$dimnames=NULL
simplified_survivalBBCC = as.data.frame(survival[,c(1,5,4,6,7)])
colnames(simplified_survivalBBCC) = c("strain", "group", "average", "condition", "cond_type")

####correct naming in table
levels(simplified_survivalBBCC$strain)[16] = "91_202_x_yHBJ1"
levels(simplified_survivalBBCC$strain)[15] = "91_202_x_VC2"
levels(simplified_survivalBBCC$strain)[14] = "91_202_x_PPC6"
levels(simplified_survivalBBCC$strain)[13]= "79_140_x_PPC6"
levels(simplified_survivalBBCC$strain)[17]= "yHBJ1_x_VC2"

######combine the two tables
survival_data = rbind(simplified_survivalBC, simplified_survivalBBCC)


#####write the table
setwd(Results)
write.table(survival_data, "survival.csv", sep="\t", row.names=F)


####supp figure 1##############
setwd(Graphs)

png("Figure_S1.png")
par(mfrow=c(2,2))
####step 1 take a control distributions for strain x (79_140_W)####
####ensure that there is only one population#####

#####panel A plot control experiment plot#####
hist(ctrl$X79_140_W, breaks=100, 
main="Control experiment (rep1)", ylab="Counts", 
xlab="Fluorescence (arbitrary units)", xlim=c(0,1000), ylim=c(0,600))
mtext("(a)", las=1, side=2, padj=-5, cex=1.8)

#####panel B plot both replicate of experiments on the same graph######
hist(exp$X79_140_W, breaks=100, 
main="Experiment (rep1)", ylab="Counts", 
xlab="Fluorescence (arbitrary units)", xlim=c(0,1000), ylim=c(0,600))
mtext("(b)", las=1, side=2, padj=-5, cex=1.8)

####panel C mixEM model#####
sub=exp$X79_140_W
	mixEM = normalmixEM(sub, k=2)
	if (mixEM$mu[1] >= 450) {
		std3 = (3*mixEM$sigma[2]) + mixEM$mu[2]
		} else{
		std3 = (3*mixEM$sigma[1]) + mixEM$mu[1]
		}
	if (std3 >= 725) {
		std3 = 600
		}
	
	cdf= ecdf(sub)
	per = round(cdf(std3),+3)
	plot.mixEM(mixEM,whichplot=2, main2="plot.mixEM (mixtools)",cex.main=1.3, ylab2="counts", xlab2="Fluorescence (arbitrary units)", breaks=100, xlim=c(0,1000))
	legend("topright", legend=c("mu=319.9731", "sigma=34.7179"), bty="n", lty=1, lwd=2, col="red")
	mtext("(c)", las=1, side=2, padj=-5, cex=1.8)

####panel D threshold live/dead#######

	plot.mixEM(mixEM,whichplot=2, main2="mu+(3*sigma)=414.1271",cex.main=1.3, ylab2="counts", xlab2="Fluorescence (arbitrary units)", breaks=100, xlim=c(0,1000))
	abline(v=std3, lty=2, lwd=2)
	segments(x0=0, y0=0.0043, x1=std3, col="black", lwd=3)
	segments(x0=std3, y0=0.0043, x1=900, col="black", lwd=3)
	segments(x0=0, y0=0.0038, y1=0.0048, lwd=3)
	segments(x0=900, y0=0.0038, y1=0.0048, lwd=3)
	text(150, y=0.008, labels=paste(per*100, "%"), cex=1.3)
	text(150,y=0.0060, labels="live", cex=1.8)
	text(700, y=0.008, labels=paste((1-per)*100, "%"), cex=1.3)
	text(700,y=0.0060, labels="dead", cex=1.8)
	mtext("(d)", las=1, side=2, padj=-5, cex=1.8)
dev.off()	




