########!paths to folders modify before use!####################
################################################################
RawData = "F:/Guillaume_Charron/Scripts_and_Data/New_Analysis/Data/00_RawData/"
DescFiles = "F:/Guillaume_Charron/Scripts_and_Data/New_Analysis/Data/01_DescFiles"	
Results = "F:/Guillaume_Charron/Scripts_and_Data/New_Analysis/Data/02_Results"		
Graphs = "F:/Guillaume_Charron/Scripts_and_Data/New_Analysis/Data/03_Graphs/"	
################################################################
################################################################

#######get raw data#######
setwd(RawData)

raw_data = read.csv("raw_data_screen.csv", header=T, sep="\t")



###########aggregate the data by strain (median)#########

agg_data=aggregate(raw_data$logsize, by=list(raw_data$strain, raw_data$condition, raw_data$cond_type , raw_data$type), FUN=median, na.rm=T)

colnames(agg_data)=c("strain", "condition", "cond_type","type", "median_logsize")


#####write file with aggregated data#####
setwd(Results)
write.table(agg_data, "agg_data.csv", sep="\t", row.names=F)

######pick the freeze data and modify the header to append it to the data

freeze_data = read.table("survival.csv", sep="\t", header=T)

###change the column names so they match the colnames of agg_data####
colnames(freeze_data) = c("strain", "condition", "cond_type", "type", "median_logsize")


####bind agg_data and freeze_data####
agg_datafr = rbind(agg_data, freeze_data)

write.table(agg_datafr, "agg_datafr.csv", sep="\t")

###################################################
###########Hybrid vs parent analysis###############
###################################################

####give new name to dataset#######

data_cross = agg_datafr

#####make a new column where we remove the _W from the names of the strains######
newnames=strsplit(as.character(data_cross[,1]),"_W")

data_cross = cbind(unlist(newnames), data_cross)
colnames(data_cross) = c("name","strain", "condition","cond_type", "type", "median")

#######make a list of the BC, BB and CC crosses

crosses = factor(unique(subset(data_cross$strain, data_cross$type == "BC" |data_cross$type == "BB"| data_cross$type == "CC")))

##### split the crosses into the names of the two parental strains
parents=strsplit(as.character(crosses), "_x_")
cross_parent=matrix(unlist(parents), ncol=2, byrow=T)
colnames(cross_parent) = c("parent_1", "parent_2")
cross_parent = as.data.frame(cross_parent)

######find the median values for the parents in each condition

data_parent1 = {}

for (i in cross_parent$parent_1){
	sub= subset (data_cross, data_cross$name == i)
	data_parent1 = rbind(data_parent1, sub)
}

data_parent2 = {}

for (i in cross_parent$parent_2){
	sub= subset (data_cross, data_cross$name == i)
	data_parent2 = rbind(data_parent2, sub)
}


data_parents = cbind (data_parent1$name, data_parent1[,3:6], data_parent2$name, data_parent2[,3:6])

########add the BC crosses values to the previous data_frame

hybrids_data = {}

for (i in crosses){

	sub = subset(data_cross, data_cross$strain == i)
	hybrids_data = rbind(hybrids_data, sub)
}

data_parents_cross = cbind (data_parents, hybrids_data)

write.table(data_parents_cross, "data_parents_cross.csv", sep="\t", row.names=F)

##########get a simpler data_frame with only the median data for B C and hybrid
##########(reorder the data at the same time for the 1st parent to be the B
##########and the second to be the C)

data_all_crosses = {}
for (i in (1:nrow(data_parents_cross))){

	if(data_parents_cross[i,4] == "B"){
		cross = cbind(data_parents_cross[i,2:3], data_parents_cross[i,1],data_parents_cross[i,5],
		data_parents_cross[i,6],data_parents_cross[i,10], data_parents_cross[i,11], 
		data_parents_cross[i,16:15])
		colnames(cross) = c("condition", "cond_type", "parent_B","parentB_value","parent_C","parentC_value", "hybrid", "median", "type")}
	else if (data_parents_cross[i,4] == "C"){
		cross = cbind(data_parents_cross[i,2:3], data_parents_cross[i,6],data_parents_cross[i,10],
		data_parents_cross[i,1],data_parents_cross[i,5], data_parents_cross[i,11], 
		data_parents_cross[i,16:15])
		colnames(cross) = c("condition", "cond_type", "parent_B","parentB_value","parent_C","parentC_value", "hybrid", "median", "type")}

data_all_crosses = rbind(data_all_crosses, cross)

}

######keep only the complete cases (remove any NA left in the data frame)

data_all_crosses = data_all_crosses[complete.cases(data_all_crosses),]


#######Create a data frame with the values parentB, parentC and Hybrid

data_mid_parent = cbind(data_all_crosses[,7], data_all_crosses[,9], 
data_all_crosses[,1:2], data_all_crosses[,c(4,6,8)])

colnames(data_mid_parent) = c("hybrid", "type", "condition", "cond_type", "median1", "median2", "medianhyb")

#######bind the mean of the parent and the best parent to the dataframe

data_mid_parent = cbind(data_mid_parent, apply(data_mid_parent[,5:6], 1, mean),
apply(data_mid_parent[,5:6], 1, max))

colnames(data_mid_parent) = c("hybrid", "type", "condition", "cond_type", "medianB", "medianC", "medianhyb", "mid_parent", "best_parent")


###calculate the additive genetic variation (a, best (or worse) parent value - midparent value)
###and the dominant genetic variation (d, hybrid value - midparent values)
###calculate d/a values and add all values to the table

a_values = data_mid_parent$best_parent - data_mid_parent$mid_parent
d_values = data_mid_parent$medianhyb - data_mid_parent$mid_parent
d_a =d_values/a_values

data_mid_parent_dominance = cbind(data_mid_parent, a_values, d_values, d_a)


########get the data on the category of dominance########

under = which(d_a < -1)
over= which(d_a > 1)
partial_best = which(d_a < 1 & d_a > 0)
partial_worse = which(d_a > -1 & d_a < 0)

d_a = cbind(d_a, rep(1, length(d_a)))
d_a[under,2] = "under-dominant"
d_a[over,2] = "over-dominant"
d_a[partial_best,2] = "partial best"
d_a[partial_worse,2] = "partial worse"

d_a = as.data.frame(d_a)
colnames(d_a) = c("d/a", "dominance")

data_mid_parent_dominance = cbind(data_mid_parent_dominance, d_a[,2])
colnames(data_mid_parent_dominance)[13] = "inheritance"

#######write a table with all the information
write.table(data_mid_parent_dominance, "data_mid_parent_dominance.csv", sep="\t", row.names=F)


#######get the data for fisher exact test for lab vs other conditions

LAB=subset(data_mid_parent_dominance, data_mid_parent_dominance$cond_type == "Lab" & data_mid_parent_dominance$type =="BC")
other=subset(data_mid_parent_dominance, data_mid_parent_dominance$cond_type != "Lab" & data_mid_parent_dominance$type =="BC")
test = matrix(c(length(which(LAB$d_a <= -1)),length(which(other$d_a <= -1)),length(which(LAB$d_a >= -1)),length(which(other$d_a >= -1))), nrow=2,ncol=2, byrow=T, dimnames=list(c("under-dominant", "other"), c("Lab", "other")))

fisher.test(test, alternative="greater")

#Fisher's Exact Test for Count Data

#data:  test
#p-value = 0.0535
#alternative hypothesis: true odds ratio is greater than 1
#95 percent confidence interval:
# 0.9814992       Inf
#sample estimates:
#odds ratio 
#  2.520737  

########get the data for Fisher exact test for proportion of positive vs negative d/a BC vs intragroup hybrids

BC=subset(data_mid_parent_dominance,  data_mid_parent_dominance$type == "BC")
BB= subset(data_mid_parent_dominance, data_mid_parent_dominance$type == "BB")
CC= subset(data_mid_parent_dominance, data_mid_parent_dominance$type == "CC")
cond_type= unique(BC$cond_type)



BC_BB = matrix(c(length(which(BC$d_a > 0)),length(which(BB$d_a > 0)),length(which(BC$d_a <0)),length(which(BB$d_a < 0))), nrow=2,ncol=2, byrow=T, dimnames=list(c("positive d/a", "negative d/a"), c("BC", "BB")))
BC_CC = matrix(c(length(which(BC$d_a > 0)),length(which(CC$d_a > 0)),length(which(BC$d_a <0)),length(which(CC$d_a < 0))), nrow=2,ncol=2, byrow=T, dimnames=list(c("positive d/a", "negative d/a"), c("BC", "CC")))

fisher.test(BC_BB, alternative = "greater")

#Fisher's Exact Test for Count Data

#data:  BC_BB
#p-value < 2.2e-16
#alternative hypothesis: true odds ratio is greater than 1
#95 percent confidence interval:
# 2.49382     Inf
#sample estimates:
#odds ratio 
#  3.185247 

fisher.test(BC_CC, alternative = "greater")

#Fisher's Exact Test for Count Data

#data:  BC_CC
#p-value = 0.9997
#alternative hypothesis: true odds ratio is greater than 1
#95 percent confidence interval:
# 0.2756809       Inf
#sample estimates:
#odds ratio 
# 0.4445836 

#######% data on the mode of inheritance

summary(BC$inheritance)

#######over-dominant   partial best  partial worse under-dominant 
#           316            240             71             45 

summary(BC$inheritance)[1]/ sum(summary(BC$inheritance)[c(1:4)])
#over-dominant 
#    0.4702381

summary(BC$inheritance)[2]/ sum(summary(BC$inheritance)[c(1:4)])
#partial best 
#   0.3571429 



###############################
########Figure 1 map###########
###############################
library(maps)
library(mapdata)

setwd(DescFiles)

####get the distribution of B and C strains
polyC= read.csv("distribution_C.csv", sep=";", header=T)
polyB = read.csv("distribution_B.csv", sep=";", header=T)

####get the limits of canadian provinces
nb_ne = read.csv("nb_ne_limits.csv", sep=";", header=T)
qc_on = read.csv("qc_on_limits.csv", sep=";", header=T)
qc_nb = read.csv("qc_nb_limits.csv", sep=";", header=T)

####add the points of the parental strains sampling locations
samplesB = read.csv("Sample_B.csv", header=T, sep=";")
samplesC = read.csv("Sample_C.csv", header=T, sep=";")


setwd(Graphs)

pdf("Figure_1.pdf")

####plot the part of the map that interests us
map("worldHires","Canada", xlim=c(-95,-60),ylim=c(40,50), col="gray90", fill=TRUE, bg="white", mar=c(4,6,4,4))
map("worldHires","USA", xlim=c(-95,-60),ylim=c(40,50), col="gray90", fill=TRUE, add=T)
map(database= "state", fill=FALSE, add=T)

text(-78,41, labels="USA",cex=1.5)
text(-74,49, labels="Canada",cex=1.5)
text(-74,48, labels="Qubec",cex=1)
text(-82,48, labels="Ontario", cex=1)
lines(qc_on$longitude, qc_on$latitude)
lines(nb_ne$longitude, nb_ne$latitude)
lines(qc_nb$longitude, qc_nb$latitude)

####add the shapes of SpB and spC distributions
polygon(polyC$longitude, polyC$latitude, col=rgb(0,0,1, 0.2), border=NA)
polygon(polyB$longitude, polyB$latitude, col=rgb(1,0,0, 0.2), border=NA)

axis(1)
axis(2)
mtext(side=1, line=3, "Longitude (degrees)")
mtext(side=2, line=3, "Latitude (degrees)")


#######plot B strains on the map
points(samplesB$longitude, samplesB$latitude, col="red", pch=15, cex=1)
points(samplesC$longitude, samplesC$latitude, col="blue", pch=19, cex=.7)

dev.off()




####################################
#############figure 2###############
####################################
library(beanplot)


setwd(Graphs)
figure = c("Maltose", "YPD35","Freeze_thaw")
data_type = BC[,c(4,12)]

purple = rgb(.58,0,.83)
blue = rgb(0,0,1)
red= rgb(1,0,0)
white= rgb(0,0,0,0)

#pdf("Figure_2.pdf", width= 15, height=10)
jpeg("Figure_2.jpg", width=15, height=10, units="in", res=600)
layout(matrix(c(1,1,1,1,2,2,3,3,4,4,5,5) , 2, 6, byrow =T), widths=c(1,1,1,1,1,1), respect=F)

par(mar=c(6,8,2,4), lwd=2)
		beanplot(d_a~cond_type,data=BC,side="first", cutmin=-10, cutmax=10, ylim=c(-10,10), col=list(c(white, "black", "black", purple), c(white, "black", "black", purple), c(white, "black", "black", purple),c(white, "black", "black", purple),c(white, "black", "black", purple), c(white, "black", "black", purple)), 
		axes=F, overallline="median", what=c(0,1,1,0), border=c(purple, purple, purple, purple, purple, purple), cex.lab=1.8, xlim=c(0.65,5.8))
		axis(2, at=c(-10,-5, -1,0,1,5,10), cex.axis=1.5, las=1)
		axis(1, labels=cond_type, at=c(1:5), cex.axis=1.5)
		title(ylab="d/a values",cex.lab=1.8)
		title(xlab="Conditions", cex.lab=1.8)
		abline(h=0, lwd=1, col="black")
		abline(h=-1, lty=2, lwd=1, col="black")
		abline(h=1, lty=2, lwd=1, col="black")
		segments(1,-10,1,10, lwd=2, col="grey")
		segments(2,-10,2,10, lwd=2, col="grey")
		segments(3,-10,3,10, lwd=2, col="grey")
		segments(4,-10,4,10, lwd=2, col="grey")
		segments(5,-10,5,10, lwd=2, col="grey")
		mtext(side=2, "(a)", las=2, line=5, adj=1, padj=-8, cex=2)
		
		beanplot(d_a~cond_type, data=BB, side="second", add=T, cutmin=-10, cutmax=10, ylim=c(-10,10), col=list(c(white, "black", "black", red), c(white, "black", "black", red), c(white, "black", "black", red),c(white, "black", "black", red),c(white, "black", "black", red), c(white, "black", "black", red)), 
		axes=F, overallline="median", what=c(0,1,1,0), border=c(red, red, red, red, red, red), cex.lab=1.8)
		

		beanplot(d_a~cond_type, data=CC, side="second", add=T, cutmin=-10, cutmax=10, ylim=c(-10,10), col=list(c(white, "black", "black", blue), c(white, "black", "black", blue), c(white, "black", "black", blue),c(white, "black", "black", blue),c(white, "black", "black", blue), c(white, "black", "black", blue)), 
		axes=F, overallline="median", what=c(0,1,1,0), border=c(blue, blue, blue, blue, blue, blue), cex.lab=1.8)

#####plot the type of dominance#####
par(mar=c(6,8,2,2))
barplot(summary(BC$inheritance), border="white", col="grey53", ylab=NA, xlim = c(0,350), xlab="Strain count", las=1, horiz=T, cex.lab=1.5, cex.axis=1.5, cex.names=1.3, names.arg=c("d/a > 1", "0 < d/a < 1 ", "-1 < d/a < 0", "d/a < -1"))
title(ylab="d/a categories", line=7, cex.lab=1.5)
mtext(side=2, "(b)", las=2, line=6, adj=1, padj=-8, cex=2)

#####part 2
for (i in figure){
par(mar=c(6,8,6,1))
	sub=subset(BC, BC$condition == i)
		if(i == "Freeze_thaw"){
			plot(c(1:3),sub[1,c(5,7,6)], xaxt="n", las=1, ylab=NA, xlab="Diploid types", ylim= c(0,1), bty="n", cex.axis=1.8, cex.lab=1.8)
			title(ylab= "% viable cells", line=5, cex.lab=1.8)
			title(main=paste("Freeze-thaw", " (median=",as.numeric(summary(sub$d_a)[3]),")", sep=""), line=0, cex.main=2)
			mtext(side=2, "(e)", las=2, line=5, adj=1, padj=-8, cex=2)
		}else if (i == "Maltose"){
			plot(c(1:3),sub[1,c(5,7,6)], bty="n", xaxt="n", las=1, ylab=NA, xlab="Diploid types", ylim= c(15,18), cex.axis= 1.8, cex.lab=1.8)
			title(ylab= "Colony size", line=5, cex.lab=1.8)
			title(main=paste(i, " (median=",as.numeric(summary(sub$d_a)[3]),")", sep=""), line=0, cex.main=2)
			legend(1,15.75, legend=c("Overdominance", "Partial dominance", "Underdominance"), lty=c(2,1,3), bty="n", cex=1.8, lwd=2)
			mtext(side=2, "(c)", las=2, line=5, adj=1, padj=-8, cex=2)
		}else{
			plot(c(1:3),sub[1,c(5,7,6)], bty="n", xaxt="n", las=1, ylab=NA, xlab="Diploid types", ylim= c(16,19), cex.axis=1.8, cex.lab=1.8)
			title(ylab= "Colony size", line=5, cex.lab=1.8)
			title(main=paste(i, " (median=",as.numeric(summary(sub$d_a)[3]),")", sep=""), line=0, cex.main=2)
			mtext(side=2, "(d)", las=2, line=5, adj=1, padj=-8, cex=2)
		}
	axis(1, at=c(1,2,3), labels = c(expression("B"["DIPLOID"]),"BC", expression("C"["DIPLOID"])), cex.axis= 1.8)


		for (j in c(1:nrow(sub))){
			
			if(sub$d_a[j] < -1){
				lines(c(1:3),sub[j,c(5,7,6)], lty = 3, lwd=4)
				points(1,sub[j,5], pch=16)
				points(2,sub[j,7], pch=16)
				points(3,sub[j,6], pch=16)
			}else if(sub$d_a[j] >1){
				lines(c(1:3),sub[j,c(5,7,6)], lty = 2, lwd=2)
				points(1,sub[j,5], pch=16)
				points(2,sub[j,7], pch=16)
				points(3,sub[j,6], pch=16)
			}else
				lines(c(1:3),sub[j,c(5,7,6)], lwd=2)
				points(1,sub[j,5], pch=16)
				points(2,sub[j,7], pch=16)
				points(3,sub[j,6], pch=16)

}
}

dev.off()


###############################
#######supp figure 2###########
###############################
setwd(Graphs)

#######create slope graphs for each condition
conditions = unique(data_mid_parent_dominance$condition)

pdf("Figure_S2.pdf")
par(mfrow=c(2,2))
for (i in conditions){

	sub=subset(BC, BC$condition == i)
	plot(c(1:3),sub[1,c(5,7,6)], xaxt="n", main = i, ylab= "Colony size", xlab= "Diploid type", ylim= c((min(sub$medianB, sub$medianC, sub$medianhyb)), (max(sub$medianB, sub$medianC, sub$medianhyb))))
	axis(1, at=c(1,2,3), labels = c("B", "BC", "C"))
		
		for (j in c(1:nrow(sub))){
			
			if(sub$d_a[j] < -1){
				lines(c(1:3),sub[j,c(5,7,6)], lty = 5, col="red", lwd=2)
				points(1,sub[j,5], pch=16)
				points(2,sub[j,7], pch=16)
				points(3,sub[j,6], pch=16)
			}else if(sub$d_a[j] >1){
				lines(c(1:3),sub[j,c(5,7,6)], lty = 5, col="green", lwd=2)
				points(1,sub[j,5], pch=16)
				points(2,sub[j,7], pch=16)
				points(3,sub[j,6], pch=16)
			}else
				lines(c(1:3),sub[j,c(5,7,6)], lwd=2)
				points(1,sub[j,5], pch=16)
				points(2,sub[j,7], pch=16)
				points(3,sub[j,6], pch=16)

}
}

dev.off()

#######################
#####supp figure 3#####
#######################

pdf("Figure_S3.pdf", width= 10, height=15)

par(mfrow= c(3,1))

par(mar=c(6,8,2,4))
		beanplot(as.numeric(as.character(BC$d_a))~BC$cond_type, cutmin=-10, cutmax=10, ylim=c(-10,10), col=list(c("grey", "black", "black", "black"), c("grey", "black", "black", "black"), c("grey", "black", "black", "black"),c("grey", "black", "black", "black"),c("grey", "black", "black", "black"), c("grey", "black", "black", "black")), 
		axes=F, overallline="median", what=c(0,1,1,0), border=c("grey", "grey", "grey", "grey", "grey", "grey"), cex.lab=1.8)
		axis(2, at=c(-10,-5, -1,0,1,5,10), cex.axis=1.5, las=1)
		axis(1, labels=cond_type, at=c(1:5), cex.axis=1.5)
		title(ylab="d/a values",cex.lab=1.8)
		title(xlab="Conditions", cex.lab=1.8)
		abline(h=0, lwd=2, col="red")
		abline(h=-1, lty=2, lwd=2, col="red")
		abline(h=1, lty=2, lwd=2, col="red")
		mtext(side=2, "(a)", las=2, line=5, adj=1, padj=-8, cex=2)

par(mar=c(6,8,2,4))
		beanplot(as.numeric(as.character(BB$d_a))~BB$cond_type, cutmin=-10, cutmax=10, ylim=c(-10,10), col=list(c("grey", "black", "black", "black"), c("grey", "black", "black", "black"), c("grey", "black", "black", "black"),c("grey", "black", "black", "black"),c("grey", "black", "black", "black"), c("grey", "black", "black", "black")), 
		axes=F, overallline="median", what=c(0,1,1,0), border=c("grey", "grey", "grey", "grey", "grey", "grey"), cex.lab=1.8)
		axis(2, at=c(-10,-5, -1,0,1,5,10), cex.axis=1.5, las=1)
		axis(1, labels=cond_type, at=c(1:5), cex.axis=1.5)
		title(ylab="d/a values",cex.lab=1.8)
		title(xlab="Conditions", cex.lab=1.8)
		abline(h=0, lwd=2, col="red")
		abline(h=-1, lty=2, lwd=2, col="red")
		abline(h=1, lty=2, lwd=2, col="red")
		mtext(side=2, "(b)", las=2, line=5, adj=1, padj=-8, cex=2)

par(mar=c(6,8,2,4))
		beanplot(as.numeric(as.character(CC$d_a))~CC$cond_type, cutmin=-10, cutmax=10, ylim=c(-10,10), col=list(c("grey", "black", "black", "black"), c("grey", "black", "black", "black"), c("grey", "black", "black", "black"),c("grey", "black", "black", "black"),c("grey", "black", "black", "black"), c("grey", "black", "black", "black")), 
		axes=F, overallline="median", what=c(0,1,1,0), border=c("grey", "grey", "grey", "grey", "grey", "grey"), cex.lab=1.8)
		axis(2, at=c(-10,-5, -1,0,1,5,10), cex.axis=1.5, las=1)
		axis(1, labels=cond_type, at=c(1:5), cex.axis=1.5)
		title(ylab="d/a values",cex.lab=1.8)
		title(xlab="Conditions", cex.lab=1.8)
		abline(h=0, lwd=2, col="red")
		abline(h=-1, lty=2, lwd=2, col="red")
		abline(h=1, lty=2, lwd=2, col="red")
		mtext(side=2, "(c)", las=2, line=5, adj=1, padj=-8, cex=2)
dev.off()

####################
####sup figure 4####
####################

pdf("Figure_S4.pdf", width= 5, height=7.5)

par(mfrow=c(3,1))

par(mar=c(6,10,2,8))
barplot(summary(BC$inheritance), border="white", col="grey53", ylab=NA, xlim = c(0,350), xlab="Strain count", las=1, horiz=T, cex.lab=1.5, cex.axis=1.5, cex.names=1.3, names.arg=c("d/a > 1", "0 < d/a < 1 ", "-1 < d/a < 0", "d/a < -1"))
title(ylab="d/a categories", line=7, cex.lab=1.5)
mtext(side=2, "(a)", las=2, line=6, adj=1, padj=-4, cex=1.5)

par(mar=c(6,10,2,8))
barplot(summary(BB$inheritance), border="white", col="grey53", ylab=NA, xlim = c(0,350), xlab="Strain count", las=1, horiz=T, cex.lab=1.5, cex.axis=1.5, cex.names=1.3, names.arg=c("d/a > 1", "0 < d/a < 1 ", "-1 < d/a < 0", "d/a < -1"))
title(ylab="d/a categories", line=7, cex.lab=1.5)
mtext(side=2, "(b)", las=2, line=6, adj=1, padj=-4, cex=1.5)

par(mar=c(6,10,2,8))
barplot(summary(CC$inheritance), border="white", col="grey53", ylab=NA, xlim = c(0,350), xlab="Strain count", las=1, horiz=T, cex.lab=1.5, cex.axis=1.5, cex.names=1.3, names.arg=c("d/a > 1", "0 < d/a < 1 ", "-1 < d/a < 0", "d/a < -1"))
title(ylab="d/a categories", line=7, cex.lab=1.5)
mtext(side=2, "(c)", las=2, line=6, adj=1, padj=-4, cex=1.5)

dev.off()

######################
######Figure_S5#######
######################

#####make a dataframe where we have the parental ID of each hybrid

data_parent_effect = cbind(data_all_crosses, apply(data_all_crosses[,c(4,6)], 1, mean),
apply(data_all_crosses[,c(4,6)], 1, max))

colnames(data_parent_effect) = c("condition", "cond_type", "parent_1", "parent1_value", "parent_2",
"parent2_value", "hybrid", "medianhyb", "type", "midparent_value", "best_parent")

####calculate the d/a values and add them to the dataframe

a_values_parent = data_parent_effect$best_parent - data_parent_effect$midparent_value
d_values_parent = data_parent_effect$medianhyb - data_parent_effect$midparent_value
d_a_parent =d_values_parent/a_values_parent

data_parent_effect = cbind(data_parent_effect, d_a_parent)

colnames(data_parent_effect) = c("condition", "cond_type", "parent_1", "parent1_value", "parent_2",
"parent2_value", "hybrid", "medianhyb", "type", "midparent_value", "best_parent", "d_a")

#####only keep the BC data to verify possible parental effects on the crosses

groupBC = subset(data_parent_effect, data_parent_effect$type == "BC")

######Rename the column parent_2 to parent_1 so theses two column can be stacked together
colnames(groupBC) = c("condition", "cond_type", "parent_1", "parent1_value", "parent_1",
"parent2_value", "hybrid", "medianhyb", "type", "midparent_value", "best_parent", "d_a")

######stack the data columns together
parentBC = rbind(groupBC[,c(3,12)], groupBC[,c(5,12)])
parentBC$parent_1 = factor(parentBC$parent_1)

######get the numer of time a strain is implicated in a cross (number of row divided by 32 conditions)
parentBCnum = {}

for(i in unique(parentBC$parent_1)){

	num = nrow(subset(parentBC, parentBC$parent_1 == i))/32
	parentBCnum= rbind(parentBCnum, c(num, i))
}

parentBCnum = as.data.frame(parentBCnum)
parentBCnum = parentBCnum[order(parentBCnum$V2),]


#######make a plot of the d/a values per parental strain
pdf("Figure_S5.pdf")
par(mar=c(7,4,3,3))
par(mfrow=c(2,1))
plot(parentBC, ylim=c(-5,5), main=NULL, xlab=NULL, las=2, ylab="d/a values")
mtext(side=1, "strain", line=5)
mtext(side=1, paste("(",parentBCnum[,1],")", sep=""), at=c(1:21), padj=-15)
mtext(side=2, "(a)", las=2, line=2, padj=-5, cex=1.5)
abline(h=0, col="red")
abline(h=1, lty=2, col="red")
abline(h=-1, lty=2, col="red")


#####calculate the median d/a for each parental strain
aggBC= aggregate(parentBC$d_a, by=list(parentBC$parent_1), FUN=median, na.rm=T)
colnames(aggBC) = c("strain", "d_a")

######make an histogram of the median d/a 
hist(aggBC$d_a, breaks=10, xlab="median d/a values", xlim=c(-1,2), main=NULL)
mtext(side=2, "(b)", las=2, line=2, padj=-5, cex=1.5)
dev.off()




